import { NullEmptyOrWhitespace } from "./catch/NullEmptyOrWhitespace";
import { ValidNumber } from "./ensure/ValidNumber";
import { EqualObjects } from "./ensure/EqualObjects";
describe("EqualObjects", () => {
    it("should return true for equal objects", () => {
        const obj1 = { a: 1, b: 2 };
        const obj2 = { a: 1, b: 2 };
        expect(EqualObjects(obj1, obj2)).toBe(true);
    });
    it("should return false for objects with different lengths", () => {
        const obj1 = { a: 1, b: 2 };
        const obj2 = { a: 1 };
        expect(EqualObjects(obj1, obj2)).toBe(false);
    });
    it("should return false for objects with different keys", () => {
        const obj1 = { a: 1, b: 2 };
        const obj2 = { c: 3, d: 4 };
        expect(EqualObjects(obj1, obj2)).toBe(false);
    });
    it("should return false for objects with different nested objects", () => {
        const obj1 = { a: { b: 1 } };
        const obj2 = { a: { b: 2 } };
        expect(EqualObjects(obj1, obj2)).toBe(false);
    });
    it("should return true for objects with same nested objects", () => {
        const obj1 = { a: { b: 1 } };
        const obj2 = { a: { b: 1 } };
        expect(EqualObjects(obj1, obj2)).toBe(true);
    });
});
describe("NullEmptyOrWhitespace", () => {
    it("should return true for null input", () => expect(NullEmptyOrWhitespace(null)).toBe(true));
    it("should return true for undefined input", () => expect(NullEmptyOrWhitespace(undefined)).toBe(true));
    it("should return true for empty string input", () => expect(NullEmptyOrWhitespace("")).toBe(true));
    it("should return true for string with only whitespace input", () => expect(NullEmptyOrWhitespace("   ")).toBe(true));
    it("should return true for empty array input", () => expect(NullEmptyOrWhitespace([])).toBe(true));
    it("should return true for empty object input", () => expect(NullEmptyOrWhitespace({})).toBe(true));
    it("should return true for empty Set input", () => expect(NullEmptyOrWhitespace(new Set())).toBe(true));
    it("should return true for empty Map input", () => expect(NullEmptyOrWhitespace(new Map())).toBe(true));
    it("should return false for non-empty input", () => {
        expect(NullEmptyOrWhitespace("hello")).toBe(false);
        expect(NullEmptyOrWhitespace([1, 2, 3])).toBe(false);
        expect(NullEmptyOrWhitespace({ key: "value" })).toBe(false);
        expect(NullEmptyOrWhitespace(new Set([1, 2, 3]))).toBe(false);
        expect(NullEmptyOrWhitespace(new Map([
            [1, "one"],
            [2, "two"],
        ]))).toBe(false);
    });
});
describe("ValidNumber", () => {
    it("should return true when input is a valid number within the specified range", () => {
        expect(ValidNumber(5, 0, 10)).toBe(true);
        expect(ValidNumber(-2.5, -10, 0)).toBe(true);
        expect(ValidNumber("3.14", 0, 5)).toBe(true);
    });
    it("should return true when input is a valid number without specifying a range", () => {
        expect(ValidNumber(5)).toBe(true);
        expect(ValidNumber("-2.5")).toBe(true);
    });
    it("should return false when input is not a number", () => {
        expect(ValidNumber("abc")).toBe(false);
        expect(ValidNumber("")).toBe(false);
    });
    it("should return false when input is less than the specified minimum value", () => {
        expect(ValidNumber(-5, 0, 10)).toBe(false);
        expect(ValidNumber("-10", 0, 5)).toBe(false);
    });
    it("should return false when input is greater than the specified maximum value", () => {
        expect(ValidNumber(15, 0, 10)).toBe(false);
        expect(ValidNumber("7", -5, 5)).toBe(false);
    });
});
